# Varhist Python Package Desicription  

## Overview  

`varhist` is a python package that allows the user to easily view a variable's history through their code. This makes debugging easier. Standart debuggers do not have this capability. Once initialized, varhist will quickly and quietly track a variable's historic values and where/when the values were changed.  

## Installation

<br>

Type `pip install varhist` in your command line or terminal

<br>

## IMPORTANT

For the varhist library to work, you have to type this at the start of your python code.
```python
import sys, varhist
sys.settrace(varhist.trace)
```
This is equivalent to initializing the module. Without this, the module will not function.
You also must put your code in a main function. This is easily done by highlighting all of your code, pressing tab, and then adding a line saying
```python
def main()
```
to the start

E.g.

```python
print("Hellow ")

## Examples  

### Basic Usage  

